ErgativeGate

Struct ErgativeGate 

pub struct ErgativeGate { /* private fields */ }
Permission gate that enforces role-based tool access.

Implementations

Source

impl ErgativeGate

pub fn new() -> Self

Create a gate with the default permission set.

Default rules:

  • Observer: Read, Glob, Grep
  • Reader: Observer tools + WebSearch, WebFetch
  • Writer: Reader tools + Edit, Write
  • Admin: wildcard * (everything)
pub fn can_invoke(&self, _agent_id: &str, role: &AgentRole, tool: &str) -> bool

Check whether an agent with a given role may invoke a tool.

pub fn filter_tools(&self, role: &AgentRole, tools: &[String]) -> Vec<String>

Filter a list of tools down to those accessible by a given role.

pub fn generate_manifest( &self, agent_id: &str, role: &AgentRole, ) -> PermissionManifest

Generate a permission manifest for an agent.

pub fn audit( &self, agent_id: &str, role: &AgentRole, tool: &str, ) -> (bool, String)

Audit a tool invocation, returning (allowed, reason).