pub struct ProvenanceChain { /* private fields */ }Expand description
A collection of provenance nodes forming one or more chains.
Implementations
Sourceimpl ProvenanceChain
impl ProvenanceChain
Sourcepub fn add_node(
&mut self,
claim: &str,
evidence: Evidence,
producer: &str,
parent_id: Option<&str>,
) -> &ProvenanceNode
pub fn add_node( &mut self, claim: &str, evidence: Evidence, producer: &str, parent_id: Option<&str>, ) -> &ProvenanceNode
Add a new provenance node and return a reference to it.
Node IDs are auto-generated using a monotonic counter (prov-1, prov-2, …).
Sourcepub fn trace_to_root(&self, node_id: &str) -> Vec<&ProvenanceNode>
pub fn trace_to_root(&self, node_id: &str) -> Vec<&ProvenanceNode>
Trace from a node back to the root, returning nodes in leaf-to-root order.
Sourcepub fn get_roots(&self) -> Vec<&ProvenanceNode>
pub fn get_roots(&self) -> Vec<&ProvenanceNode>
Return all root nodes (nodes with no parent).
Sourcepub fn get_leaves(&self) -> Vec<&ProvenanceNode>
pub fn get_leaves(&self) -> Vec<&ProvenanceNode>
Return all leaf nodes (nodes that are not referenced as a parent by any other node).
Sourcepub fn weakest_link(&self, node_id: &str) -> EvidenceClass
pub fn weakest_link(&self, node_id: &str) -> EvidenceClass
Return the weakest EvidenceClass along the chain from a node to root.
Sourcepub fn chain_confidence(&self, node_id: &str) -> f64
pub fn chain_confidence(&self, node_id: &str) -> f64
Compute the product of confidence values along the chain from a node to root.
Returns 0.0 if the node is not found.